@@ -2,7 +2,10 @@ import re
 import enum
 import inspect
 import itertools
-import warnings
+
+from typing import Callable, List, Dict, TYPE_CHECKING
+
+from flask import Flask
 
 from flask_discord_interactions.context import Context, AsyncContext
 from flask_discord_interactions.models import (
@@ -19,6 +22,11 @@ from flask_discord_interactions.models import (
     Attachment,
 )
 
+if TYPE_CHECKING:
+    from flask_discord_interactions.discord import DiscordInteractions
+
+_type = type
+
 
 class Command:
     """
@@ -26,76 +34,70 @@ class Command:
 
     Attributes
     ----------
-    command
+    command: Callable
         Function to call when the command is invoked.
-    name
+    name: str
         Name for this command (appears in the Discord client). If omitted,
         infers the name based on the name of the function.
-    name_localizations
+    name_localizations: Dict[str, str]
         Localization dictionary for name field.
-    description
+    description: str
         Description for this command (appears in the Discord client). If
         omitted, infers the description based on the docstring of the function,
         or sets the description to "No description", if ``ApplicationCommandType``
         is ``CHAT_INPUT``, else set description to ``None``.
-    description_localizations
+    description_localizations: Dict[str, str]
         Localization dictionary for description field.
-    options
+    options: List[Option]
         Array of options that can be passed to this command. If omitted,
         infers the options based on the function parameters and type
         annotations.
-    annotations
+    annotations: Dict[str, str]
         Dictionary of descriptions for each option provided. Use this only if
         you want the options to be inferred from the parameters and type
         annotations. Do not use with ``options``. If omitted, and if
         ``options`` is not provided, option descriptions default to
         "No description".
-    command_type
+    type: int
         Type for this command (depend on the action in the Discord client).
         The value is in ``ApplicationCommandType``. If omitted, set the default
         value to ``ApplicationCommandType.CHAT_INPUT``.
-    default_permission
-        Deprecated as of v1.5! Whether the command is enabled by default.
-    default_member_permissions
+    default_member_permissions: int
         A permission integer defining the required permissions a user must have to run the command
-    dm_permission
+    dm_permission: bool
         Indicates whether the command can be used in DMs
-    permissions
-        List of permission overwrites.
-    discord
+    discord: DiscordInteractions
         DiscordInteractionsBlueprint instance which this Command is associated
         with.
     """
 
     def __init__(
         self,
-        command,
-        name,
-        description,
-        options,
-        annotations,
-        command_type=ApplicationCommandType.CHAT_INPUT,
-        default_permission=None,
-        default_member_permissions=None,
-        dm_permission=None,
-        permissions=None,
-        name_localizations=None,
-        description_localizations=None,
-        discord=None,
+        command: Callable,
+        name: str,
+        description: str,
+        *,
+        options: List[Option],
+        annotations: Dict[str, str],
+        type: int = ApplicationCommandType.CHAT_INPUT,
+        default_member_permissions: int = None,
+        dm_permission: bool = None,
+        name_localizations: Dict[str, str] = None,
+        description_localizations: Dict[str, str] = None,
+        discord: "DiscordInteractions" = None,
     ):
         self.command = command
         self.name = name
         self.description = description
         self.options = options
         self.annotations = annotations or {}
-        self.type = command_type
-        self.default_permission = default_permission
+        self.type = type
         self.default_member_permissions = default_member_permissions
         self.dm_permission = dm_permission
-        self.permissions = permissions
         self.name_localizations = name_localizations
         self.description_localizations = description_localizations
         self.discord = discord
+        self.id = None
 
         if self.name is None:
             self.name = command.__name__
@@ -145,7 +147,7 @@ class Command:
                 annotation = parameter.annotation
                 autocomplete = False
 
-                if type(annotation) == Autocomplete:
+                if _type(annotation) == Autocomplete:
                     annotation = annotation.t
                     autocomplete = True
 
@@ -205,19 +207,21 @@ class Command:
 
                 self.options.append(option)
 
-    def make_context_and_run(self, discord, app, data):
+    def make_context_and_run(
+        self, *, discord: "DiscordInteractions", app: Flask, data: dict
+    ):
         """
         Creates the :class:`Context` object for an invocation of this
         command, then invokes itself.
 
         Parameters
         ----------
-        discord
+        discord: DiscordInteractions
             The :class:`DiscordInteractions` object used to receive this
             interaction.
-        app
+        app: Flask
             The Flask app used to receive this interaction.
-        data
+        data: dict
             The incoming interaction data.
 
         Returns
@@ -239,13 +243,13 @@ class Command:
         else:
             return Message.from_return_value(result)
 
-    def run(self, context, *args, **kwargs):
+    def run(self, context: Context, *args, **kwargs):
         """
         Invokes the function defining this command.
 
         Parameters
         ----------
-        context
+        context: Context
             The :class:`Context` object representing the current state.
         *args
             Any subcommands of the current command being called.
@@ -266,16 +270,6 @@ class Command:
             "description_localizations": self.description_localizations,
         }
 
-        # Keeping this here not to break any bots using the old system
-        if self.default_permission is not None:
-            data["default_permission"] = self.default_permission
-            warnings.warn(
-                "Deprecated! As of v1.5, the old default_permission is deprecated in favor of "
-                "the new default_member_permissions",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         if self.default_member_permissions is not None:
             data["default_member_permissions"] = str(self.default_member_permissions)
 
@@ -284,9 +278,6 @@ class Command:
 
         return data
 
-    def dump_permissions(self):
-        return [permission.dump() for permission in self.permissions]
-
     def autocomplete(self):
         """
         Register an autocomplete handler function for this command.
@@ -317,26 +308,27 @@ class SlashCommandSubgroup(Command):
 
     Attributes
     ----------
-    name
+    name: str
         The name of this subgroup, shown in the Discord client.
-    name_localizations
+    name_localizations: Dict[str, str]
         A dict of localized names for this subgroup.
-    description
+    description: str
         The description of this subgroup, shown in the Discord client.
-    description_localizations
+    description_localizations: Dict[str, str]
         A dict of localized descriptions for this subgroup.
-    is_async
+    is_async: bool
         Whether the subgroup should be considered async (if subcommands
         get an :class:`AsyncContext` instead of a :class:`Context`.)
     """
 
     def __init__(
         self,
-        name,
-        description,
-        name_localizations=None,
-        description_localizations=None,
-        is_async=False,
+        name: str,
+        description: str,
+        *,
+        name_localizations: Dict[str, str] = None,
+        description_localizations: Dict[str, str] = None,
+        is_async: bool = False,
     ):
         self.name = name
         self.description = description
@@ -345,39 +337,38 @@ class SlashCommandSubgroup(Command):
         self.name_localizations = name_localizations
         self.description_localizations = description_localizations
 
-        self.default_permission = None
         self.default_member_permissions = None
         self.dm_permission = None
-        self.permissions = None
 
         self.is_async = is_async
 
     def command(
         self,
-        name=None,
-        description=None,
-        name_localizations=None,
-        description_localizations=None,
-        options=None,
-        annotations=None,
+        name: str = None,
+        description: str = None,
+        *,
+        name_localizations: Dict[str, str] = None,
+        description_localizations: Dict[str, str] = None,
+        options: List[Option] = None,
+        annotations: Dict[str, str] = None,
     ):
         """
         Decorator to create a new Subcommand of this Subgroup.
 
         Parameters
         ----------
-        name
+        name: str
             The name of the command, as displayed in the Discord client.
-        name_localizations
+        name_localizations: Dict[str, str]
             A dict of localized names for the command.
-        description
+        description: str
             The description of the command.
-        description_localizations
+        description_localizations: Dict[str, str]
             A dict of localized descriptions for the command.
-        options
+        options: List[Option]
             A list of options for the command, overriding the function's
             keyword arguments.
-        annotations
+        annotations: Dict[str, str]
             If ``options`` is not provided, descriptions for each of the
             options defined in the function's keyword arguments.
         """
@@ -402,6 +393,11 @@ class SlashCommandSubgroup(Command):
         """
         Returns an array of options that can be passed to this command.
         Computed based on the options of each subcommand or subcommand group.
+
+        Returns
+        -------
+        List[Option]
+            The options for this command.
         """
         options = []
         for command in self.subcommands.values():
@@ -420,7 +416,7 @@ class SlashCommandSubgroup(Command):
 
         Parameters
         ----------
-        context
+        context: Context
             The :class:`Context` object representing the current state.
         *args
             List of subcommands of the current command group being invoked.
@@ -436,37 +432,31 @@ class SlashCommandGroup(SlashCommandSubgroup):
 
     Attributes
     ----------
-    name
+    name: str
         The name of this subgroup, shown in the Discord client.
-    name_localizations
+    name_localizations: Dict[str, str]
         A dict of localized names for this subgroup.
-    description
+    description: str
         The description of this subgroup, shown in the Discord client.
-    description_localizations
+    description_localizations: Dict[str, str]
         A dict of localized descriptions for this subgroup.
-    is_async
+    is_async: bool
         Whether the subgroup should be considered async (if subcommands
         get an :class:`AsyncContext` instead of a :class:`Context`.)
-    default_permission
-        Whether the subgroup is enabled by default. Default is True.
-    default_member_permissions:
+    default_member_permissions: int
         Permission integer setting permission defaults for a command
-    dm_permission
+    dm_permission: int
         Indicates whether the command can be used in DMs
-    permissions
-        List of permission overwrites. These apply to all subcommands of this
-        group.
     """
 
     def __init__(
         self,
         name,
         description,
+        *,
         is_async=False,
-        default_permission=None,
         default_member_permissions=None,
         dm_permission=None,
-        permissions=None,
         name_localizations=None,
         description_localizations=None,
     ):
@@ -475,10 +465,8 @@ class SlashCommandGroup(SlashCommandSubgroup):
         self.subcommands = {}
         self.type = ApplicationCommandType.CHAT_INPUT
 
-        self.default_permission = default_permission
         self.default_member_permissions = default_member_permissions
         self.dm_permission = dm_permission
-        self.permissions = permissions
         self.name_localizations = name_localizations
         self.description_localizations = description_localizations
 
@@ -486,11 +474,12 @@ class SlashCommandGroup(SlashCommandSubgroup):
 
     def subgroup(
         self,
-        name,
-        description="No description",
-        name_localizations=None,
-        description_localizations=None,
-        is_async=False,
+        name: str,
+        description: str = "No description",
+        *,
+        name_localizations: Dict[str, str] = None,
+        description_localizations: Dict[str, str] = None,
+        is_async: bool = False,
     ):
         """
         Create a new :class:`SlashCommandSubroup`
@@ -498,21 +487,25 @@ class SlashCommandGroup(SlashCommandSubgroup):
 
         Parameters
         ----------
-        name
+        name: str
             The name of the subgroup, as displayed in the Discord client.
-        name_localizations
+        name_localizations: Dict[str, str]
             A dict of localized names for the subgroup.
-        description
+        description: str
             The description of the subgroup. Defaults to "No description".
-        description_localizations
+        description_localizations: Dict[str, str]
             A dict of localized descriptions for the subgroup.
-        is_async
+        is_async: bool
             Whether the subgroup should be considered async (if subcommands
             get an :class:`AsyncContext` instead of a :class:`Context`.)
         """
 
         group = SlashCommandSubgroup(
-            name, description, name_localizations, description_localizations, is_async
+            name,
+            description,
+            name_localizations=name_localizations,
+            description_localizations=description_localizations,
+            is_async=is_async,
         )
         self.subcommands[name] = group
         return group
